import {
  styled
} from "../../chunk.PZM455AG.js";
import "../../chunk.XJDNB3KX.js";
import "../../chunk.7VFLWIC7.js";

// src/runtime/internal/components/CodeSnippet.tsx
import {
  createElement,
  useMemo
} from "react";
function createSnippetComponent(parseResult) {
  return function BoundCodeSnippet(props) {
    return /* @__PURE__ */ createElement(CodeSnippet, {
      ...props,
      parseResult
    });
  };
}
function CodeSnippetComponent(props) {
  const {bgColor, fgColor, firstLineOffset, language, tokensByLine} = props.parseResult;
  const fromLine = Math.max(0, (props.fromLine || 1) - 1);
  const toLine = Math.max(fromLine + 1, props.toLine || tokensByLine.length);
  const lineSlice = tokensByLine.slice(fromLine, toLine);
  const firstLineNumber = firstLineOffset + fromLine + 1;
  const emphasizeLines = useMemo(() => (props.emphasizeRanges || []).reduce((lines, [fromLine2, toLine2]) => {
    for (let i = fromLine2; i <= toLine2; i++) {
      lines.add(i);
    }
    return lines;
  }, new Set()), [props.emphasizeRanges]);
  const bgHex = hexToRgb(bgColor);
  const fgHex = hexToRgb(fgColor);
  const classNames = [props.className, emphasizeLines.size ? "has-emphasis" : void 0].filter(Boolean).join(" ");
  return /* @__PURE__ */ createElement("pre", {
    "data-lang": language || "unknown",
    className: classNames,
    style: {
      backgroundColor: bgColor,
      color: fgColor,
      "--bgColor": bgHex ? `${bgHex.r}, ${bgHex.g}, ${bgHex.b}` : bgColor,
      "--fgColor": fgHex ? `${fgHex.r}, ${fgHex.g}, ${fgHex.b}` : fgColor
    }
  }, /* @__PURE__ */ createElement("code", null, lineSlice.map((line, lineIdx) => {
    const lineNumber = firstLineNumber + lineIdx;
    return /* @__PURE__ */ createElement("span", {
      className: emphasizeLines.has(lineNumber) ? "has-emphasis" : void 0,
      "data-lineno": lineNumber,
      key: lineNumber
    }, line.map((token, tokenIdx) => {
      const [value, fgColor2] = Array.isArray(token) ? token : [token];
      return /* @__PURE__ */ createElement("span", {
        key: tokenIdx,
        style: {color: fgColor2}
      }, value);
    }), lineIdx < lineSlice.length - 1 ? "\n" : null);
  })));
}
var CodeSnippet = styled(CodeSnippetComponent)`
  pre&[data-lang] {
    position: relative;
    overflow: auto;
    padding-left: 0;
    padding-right: 0;
  }

  & > code {
    padding: 0.857143em 0;
    display: block;
    min-width: 100%;
  }

  &::before {
    content: attr(data-lang);
    margin-right: 0;
    text-align: right;
    position: sticky;
    right: 1.14286rem;
    top: 0.857143rem;
    opacity: 80%;
    text-shadow: black 0 0 4px;
    display: block;
    float: right;
    background-color: var(--bgColor, transparent);
    z-index: 1;
  }

  & span[data-lineno] {
    display: block;
    transition: filter 0.2s ease-in-out;
  }

  & span[data-lineno]::before {
    display: inline-block;
    position: sticky;
    left: 0;
    content: attr(data-lineno);
    background-color: rgb(var(--bgColor, transparent));
    color: rgba(var(--fgColor), 0.8);
    text-align: right;
    padding-right: 0.4rem;
    margin-right: 0.4em;
    transition: filter, border-color 0.2s ease-in-out;
    width: 4rem;
  }

  span[data-lineno].has-emphasis::before {
    border-left: 0.3rem solid rgba(var(--fgColor), 0.8);
  }

  &.has-emphasis {
    span[data-lineno]:not(.has-emphasis) {
      filter: saturate(0.75) brightness(0.8);
    }

    &:hover {
      span[data-lineno] {
        filter: saturate(1) brightness(1);

        &.has-emphasis::before {
          border-left: 0.3rem solid rgba(var(--fgColor), 0.9);
        }
      }
    }
  }

  &.has-emphasis span[data-lineno].has-emphasis {
    opacity: 1;
    background-color: rgb(var(--bgColor, transparent));
    filter: contrast(1.2);
  }
`;
function hexToRgb(hex) {
  var shorthandRegex = /^#?([a-f\d])([a-f\d])([a-f\d])$/i;
  hex = hex.replace(shorthandRegex, function(_, r, g, b) {
    return r + r + g + g + b + b;
  });
  var result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
  return result ? {
    r: parseInt(result[1], 16),
    g: parseInt(result[2], 16),
    b: parseInt(result[3], 16)
  } : null;
}
export {
  CodeSnippet,
  createSnippetComponent
};
